@@ -59,6 +59,8 @@ pub fn set_mathml(mathml_str: String) -> Result<String> {
         // if these are present when resent to MathJaX, MathJaX crashes (https://github.com/mathjax/MathJax/issues/2822)
         static ref MATHJAX_V2: Regex = Regex::new(r#"class *= *['"]MJX-.*?['"]"#).unwrap();
         static ref MATHJAX_V3: Regex = Regex::new(r#"class *= *['"]data-mjx-.*?['"]"#).unwrap();
+        static ref NAMESPACE_DECL: Regex = Regex::new(r#"xmlns:[[:alpha:]]+"#).unwrap();     // very limited namespace prefix match
+        static ref PREFIX: Regex = Regex::new(r#"(</?)[[:alpha:]]+:"#).unwrap();     // very limited namespace prefix match
     }
 
     NAVIGATION_STATE.with(|nav_stack| {
@@ -74,6 +76,13 @@ pub fn set_mathml(mathml_str: String) -> Result<String> {
 
         let mathml_str = MATHJAX_V2.replace_all(&mathml_str, "");
         let mathml_str = MATHJAX_V3.replace_all(&mathml_str, "");
+
+        // the speech rules use the xpath "name" function and that includes the prefix
+        // getting rid of the prefix properly probably involves a recursive replacement in the tree
+        // if the prefix is used, it is almost certainly something like "m" or "mml", so this cheat will work.
+        let mathml_str = NAMESPACE_DECL.replace(&mathml_str, "xmlns");  // do this before the PREFIX replace!
+        let mathml_str = PREFIX.replace_all(&mathml_str, "$1");
+
         let new_package = parser::parse(&mathml_str);    
         if let Err(e) = new_package {
             bail!("Invalid MathML input:\n{}\nError is: {}", &mathml_str, &e.to_string());
@@ -81,7 +90,8 @@ pub fn set_mathml(mathml_str: String) -> Result<String> {
         crate::speech::SpeechRules::initialize_all_rules()?;
 
         let new_package = new_package.unwrap();
-        let mathml = cleanup_mathml(get_element(&new_package))?;
+        let mathml = get_element(&new_package);
+        let mathml = cleanup_mathml(mathml)?;
         let mathml_string = mml_to_string(&mathml);
         old_package.replace(new_package);
 
@@ -407,6 +417,8 @@ fn trim_doc(doc: &Document) {
 
 /// Not really meant to be public -- used by tests in some packages
 pub fn trim_element(e: &Element) {
+    const TEMP_NBSP: &str = "\u{F8FB}";
+
     // "<mtext>this is text</mtext" results in 3 text children
     // these are combined into one child as it makes code downstream simpler
     if is_leaf(*e) {
@@ -432,7 +444,6 @@ pub fn trim_element(e: &Element) {
     }
 
     // hack to avoid non-breaking whitespace from being removed -- move to a unique non-whitespace char then back
-    const TEMP_NBSP: &str = "\u{F8FB}";
     let trimmed_text = single_text.replace(' ', TEMP_NBSP).trim().replace(TEMP_NBSP, " ");
     if !e.children().is_empty() && !trimmed_text.is_empty() {
         // FIX: we have a problem -- what should happen???
@@ -472,7 +483,10 @@ pub fn trim_element(e: &Element) {
 
         // get rid of the old children and replace with the text we just built
         mathml_leaf.clear_children();
-        mathml_leaf.set_text(&text);
+
+        // hack to avoid non-breaking whitespace from being removed -- move to a unique non-whitespace char then back
+        let trimmed_text = text.replace(' ', TEMP_NBSP).trim().replace(TEMP_NBSP, " ");
+        mathml_leaf.set_text(&trimmed_text);
     }
 }
 
